# Bombard examples

To use example as campaign name `bombard --example <example name>`.

### Available examples

#### simpleton
The simplest possible campaign for `jsonplaceholder`

#### simplest
Gets posts list from `jsonplaceholder` and show 1st post

#### simple
Gets posts list from `jsonplaceholder` and show 1st three posts

#### easy
Iterates in number of lists on `jsonplaceholder`
